<?php

declare(strict_types=1);

namespace Drupal\path_tools\FormDecorator;

use Drupal\Core\Form\FormStateInterface;
use Drupal\form_decorator\Attribute\FormDecorator;
use Drupal\form_decorator\FormDecoratorBase;

/**
 * Plugin implementation for "form_taxonomy_vocabulary_form_alter".
 */
#[FormDecorator('form_taxonomy_vocabulary_form_alter')]
final class TaxonomyVocabularyFormAlter extends FormDecoratorBase {

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, ...$args) {
    $form = parent::buildForm($form, $form_state, ...$args);

    $path_based_breadcrumb = $this->getEntity()->getThirdPartySetting('path_tools', 'path_based_breadcrumb', FALSE);
    $form['path_tools'] = [
      '#type' => 'details',
      '#title' => $this->t('Path tools suite'),
      '#group' => 'additional_settings',
      '#open' => $path_based_breadcrumb,
    ];

    $form['path_tools']['path_tools_path_based_breadcrumb'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable path based breadcrumbs'),
      '#suffix' => $this->t('Replaces the default term breadcrumb builder with a path based one.'),
      '#default_value' => $path_based_breadcrumb,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    $vocabulary = $this->getEntity();
    $vocabulary->setThirdPartySetting('path_tools', 'path_based_breadcrumb', $form_state->getValue('path_tools_path_based_breadcrumb'));

    $this->inner->setEntity($vocabulary);
    return $this->inner->save($form, $form_state);
  }

}
