<?php

namespace Drupal\path_tools;

use Drupal\Core\Entity\ContentEntityInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Service description.
 */
interface ParentEntityFromPathServiceInterface {

  /**
   * Trys to load an entity from the path.
   *
   * @return ContentEntityInterface|null
   *   Returns the entity if available.
   */
  public function getPathBasedParentEntity(): ?ContentEntityInterface;

  /**
   * Loads the entities from the path.
   *
   * @return array
   *   Returns the determined entities.
   */
  public function getPathBasedParentEntities(): array;

  /**
   * Matches a path in the router.
   *
   * @param string $path
   *   The request path with a leading slash.
   * @param array $exclude
   *   An array of paths or system paths to skip.
   *
   * @return \Symfony\Component\HttpFoundation\Request
   *   A populated request object or NULL if the path couldn't be matched.
   */
  public function getRequestForPath($path, array $exclude): ?Request;

}
